@@ -8,11 +8,13 @@ import json
 import xyzservices
 from datetime import date, timedelta
 from math import isnan
+from branca.colormap import linear, ColorMap
+from IPython.display import display
 import warnings
 
 from ipywidgets import (
     Widget, DOMWidget, Box, Color, CallbackDispatcher, widget_serialization,
-    interactive, Style
+    interactive, Style, Output
 )
 
 from ipywidgets.widgets.trait_types import InstanceDict
@@ -22,7 +24,6 @@ from traitlets import (
     CFloat, Float, Unicode, Int, Tuple, List, Instance, Bool, Dict, Enum,
     link, observe, default, validate, TraitError, Union, Any
 )
-
 from ._version import EXTENSION_VERSION
 
 from .projections import projections
@@ -139,6 +140,19 @@ class Layer(Widget, InteractMixin):
     pane = Unicode('').tag(sync=True)
 
     options = List(trait=Unicode()).tag(sync=True)
+    subitems = Tuple().tag(trait=Instance(Widget), sync=True, **widget_serialization)
+
+    @validate('subitems')
+    def _validate_subitems(self, proposal):
+        '''Validate subitems list.
+
+        Makes sure only one instance of any given subitem can exist in the
+        subitem list.
+        '''
+        subitem_ids = [subitem.model_id for subitem in proposal.value]
+        if len(set(subitem_ids)) != len(subitem_ids):
+            raise Exception('duplicate subitem detected, only use each subitem once')
+        return proposal.value
 
     def __init__(self, **kwargs):
         super(Layer, self).__init__(**kwargs)
@@ -576,6 +590,8 @@ class TileLayer(RasterLayer):
         Whether the layer is wrapped around the antimeridian.
     tms: boolean, default False
         If true, inverses Y axis numbering for tiles (turn this on for TMS services).
+    zoom_offset: int, default 0
+        The zoom number used in tile URLs will be offset with this value.
     show_loading: boolean, default False
         Whether to show a spinner when tiles are loading.
     loading: boolean, default False (dynamically updated)
@@ -600,6 +616,7 @@ class TileLayer(RasterLayer):
     detect_retina = Bool(False).tag(sync=True, o=True)
     no_wrap = Bool(False).tag(sync=True, o=True)
     tms = Bool(False).tag(sync=True, o=True)
+    zoom_offset = Int(0).tag(sync=True, o=True)
     show_loading = Bool(False).tag(sync=True)
     loading = Bool(False, read_only=True).tag(sync=True)
 
@@ -1161,7 +1178,9 @@ class LayerGroup(Layer):
         Parameters
         ----------
         layer: layer instance
-            The new layer to include in the group.
+            The new layer to include in the group. This can also be an object
+            with an ``as_leaflet_layer`` method which generates a compatible
+            layer type.
         """
 
         if isinstance(layer, dict):
@@ -1399,7 +1418,7 @@ class Choropleth(GeoJSON):
         Minimum data value for the color mapping.
     value_max: float, default None
         Maximum data value for the color mapping.
-    colormap: branca.colormap.ColorMap instance, default None
+    colormap: branca.colormap.ColorMap instance, default linear.OrRd_06
         The colormap used for the effect.
     key_on: string, default "id"
         The feature key to use for the colormap effect.
@@ -1415,7 +1434,7 @@ class Choropleth(GeoJSON):
     choro_data = Dict()
     value_min = CFloat(None, allow_none=True)
     value_max = CFloat(None, allow_none=True)
-    colormap = Any()
+    colormap = Instance(ColorMap, default_value=linear.OrRd_06)
     key_on = Unicode('id')
     nan_color = Unicode('black')
     nan_opacity = CFloat(0.4)
@@ -1425,14 +1444,6 @@ class Choropleth(GeoJSON):
     def _update_data(self, change):
         self.data = self._get_data()
 
-    @default('colormap')
-    def _default_colormap(self):
-        try:
-            from branca.colormap import linear
-        except ImportError:
-            raise RuntimeError("The Choropleth needs branca to be installed, please run `pip install branca`")
-        return linear.OrRd_06
-
     @default('style_callback')
     def _default_style_callback(self):
         def compute_style(feature, colormap, choro_data):
@@ -2031,6 +2042,38 @@ class LegendControl(Control):
         self.send_state()
 
 
+class ColormapControl(WidgetControl):
+    """ColormapControl class, with WidgetControl as parent class.
+
+    A control which contains a colormap.
+
+    Attributes
+    ----------
+    caption : str, default 'caption'
+        The caption of the colormap.
+    colormap: branca.colormap.ColorMap instance, default linear.OrRd_06
+        The colormap used for the effect.
+    value_min : float, default 0.0
+        The minimal value taken by the data to be represented by the colormap.
+    value_max : float, default 1.0
+        The maximal value taken by the data to be represented by the colormap.
+    """
+    caption = Unicode('caption')
+    colormap = Instance(ColorMap, default_value=linear.OrRd_06)
+    value_min = CFloat(0.0)
+    value_max = CFloat(1.0)
+
+    @default('widget')
+    def _default_widget(self):
+        widget = Output(layout={'height': '40px', 'width': '520px', 'margin': '0px -19px 0px 0px'})
+        with widget:
+            colormap = self.colormap.scale(self.value_min, self.value_max)
+            colormap.caption = self.caption
+            display(colormap)
+
+        return widget
+
+
 class SearchControl(Control):
     """ SearchControl class, with Control as parent class.
 
@@ -2493,6 +2536,9 @@ class Map(DOMWidget, InteractMixin):
         item: Layer or Control instance
             The layer or control to add.
         """
+        if hasattr(item, 'as_leaflet_layer'):
+            item = item.as_leaflet_layer()
+
         if isinstance(item, Layer):
             if isinstance(item, dict):
                 item = basemap_to_tiles(item)
@@ -2504,6 +2550,7 @@ class Map(DOMWidget, InteractMixin):
             if item.model_id in self._control_ids:
                 raise ControlException('control already on map: %r' % item)
             self.controls = tuple([control for control in self.controls] + [item])
+
         return self
 
     def remove(self, item):
@@ -2602,4 +2649,5 @@ class Map(DOMWidget, InteractMixin):
                 else:
                     self.zoom -= 1
                     await wait_for_change(self, 'bounds')
+
                     break
