@@ -24,14 +24,16 @@ export class LeafletLayerModel extends widgets.WidgetModel {
       popup_min_width: 50,
       popup_max_width: 300,
       popup_max_height: null,
-      pane: ''
+      pane: '',
+      subitems: [],
     };
   }
 }
 
 LeafletLayerModel.serializers = {
   ...widgets.WidgetModel.serializers,
-  popup: { deserialize: widgets.unpack_models }
+  popup: { deserialize: widgets.unpack_models },
+  subitems: { deserialize: widgets.unpack_models },
 };
 
 export class LeafletUILayerModel extends LeafletLayerModel {
@@ -39,7 +41,7 @@ export class LeafletUILayerModel extends LeafletLayerModel {
     return {
       ...super.defaults(),
       _view_name: 'LeafletUILayerView',
-      _model_name: 'LeafletUILayerModel'
+      _model_name: 'LeafletUILayerModel',
     };
   }
 }
@@ -51,22 +53,55 @@ export class LeafletLayerView extends utils.LeafletWidgetView {
     this.popup_content_promise = Promise.resolve();
   }
 
+  remove_subitem_view(child_view) {
+    if (child_view instanceof LeafletLayerView) {
+      this.map_view.obj.removeLayer(child_view.obj);
+    } else {
+      this.map_view.obj.removeControl(child_view.obj);
+    }
+    child_view.remove();
+  }
+
+  add_subitem_model(child_model) {
+    return this.create_child_view(child_model, {
+      map_view: this,
+    }).then((view) => {
+      if (child_model instanceof LeafletLayerModel) {
+        this.map_view.obj.addLayer(view.obj);
+      } else {
+        this.map_view.obj.addControl(view.obj);
+      }
+
+      //Trigger the displayed event of the child view.
+      this.displayed.then(() => {
+        view.trigger('displayed', this);
+      });
+      return view;
+    });
+  }
+
   render() {
     return Promise.resolve(this.create_obj()).then(() => {
       this.leaflet_events();
       this.model_events();
       this.bind_popup(this.model.get('popup'));
-      this.listenTo(this.model, 'change:popup', function(model, value) {
+      this.listenTo(this.model, 'change:popup', function (model, value) {
         this.bind_popup(value);
       });
       this.update_pane();
+      this.subitem_views = new widgets.ViewList(
+        this.add_subitem_model,
+        this.remove_subitem_view,
+        this
+      );
+      this.subitem_views.update(this.model.get('subitems'));
     });
   }
 
   update_pane() {
     const pane = this.model.get('pane');
     if (pane !== '') {
-      L.setOptions(this.obj, {pane});
+      L.setOptions(this.obj, { pane });
     }
   }
 
@@ -75,15 +110,15 @@ export class LeafletLayerView extends utils.LeafletWidgetView {
     if (this.obj.on) {
       this.obj.on(
         'click dblclick mousedown mouseup mouseover mouseout',
-        event => {
+        (event) => {
           this.send({
             event: 'interaction',
             type: event.type,
-            coordinates: [event.latlng.lat, event.latlng.lng]
+            coordinates: [event.latlng.lat, event.latlng.lng],
           });
         }
       );
-      this.obj.on('popupopen', event => {
+      this.obj.on('popupopen', () => {
         // This is a workaround for making maps rendered correctly in popups
         window.dispatchEvent(new Event('resize'));
       });
@@ -109,7 +144,7 @@ export class LeafletLayerView extends utils.LeafletWidgetView {
       this.listenTo(
         this.model,
         'change:' + key,
-        function() {
+        function () {
           L.setOptions(this.obj, this.get_options());
         },
         this
@@ -123,15 +158,24 @@ export class LeafletLayerView extends utils.LeafletWidgetView {
     this.listenTo(
       this.model,
       'change:pane',
-      function() {
+      function () {
         this.map_view.rerender();
       },
       this
     );
+    this.listenTo(
+      this.model,
+      'change:subitems',
+      function () {
+        this.subitem_views.update(this.subitems);
+      },
+      this
+    );
   }
 
   remove() {
     super.remove();
+    this.subitem_views.remove();
     this.popup_content_promise.then(() => {
       if (this.popup_content) {
         this.popup_content.remove();
@@ -146,9 +190,8 @@ export class LeafletLayerView extends utils.LeafletWidgetView {
     }
     if (value) {
       this.popup_content_promise = this.popup_content_promise.then(() => {
-        return this
-          .create_child_view(value, { map_view: this.map_view })
-          .then(view => {
+        return this.create_child_view(value, { map_view: this.map_view }).then(
+          (view) => {
             // If it's a Popup widget
             if (value.name == 'LeafletPopupModel') {
               this.obj.bindPopup(view.obj, this.popup_options());
@@ -165,7 +208,8 @@ export class LeafletLayerView extends utils.LeafletWidgetView {
             }
             this.popup_content = view;
             this.trigger('popup_content:created');
-          });
+          }
+        );
       });
     }
     return this.popup_content_promise;
@@ -175,7 +219,7 @@ export class LeafletLayerView extends utils.LeafletWidgetView {
     return {
       minWidth: this.model.get('popup_min_width'),
       maxWidth: this.model.get('popup_max_width'),
-      maxHeight: this.model.get('popup_max_height')
+      maxHeight: this.model.get('popup_max_height'),
     };
   }
 
